@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@strace.io>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2015-2021 The strace developers.
+ * Copyright (c) 2015-2024 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,16 +12,14 @@
 #include "tests.h"
 #include "scno.h"
 
-#if defined __NR_name_to_handle_at && defined __NR_open_by_handle_at
+#include <assert.h>
+#include <errno.h>
+#include <inttypes.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <unistd.h>
 
-# include <assert.h>
-# include <errno.h>
-# include <inttypes.h>
-# include <fcntl.h>
-# include <stdio.h>
-# include <unistd.h>
-
-# include "secontext.h"
+#include "secontext.h"
 
 enum assert_rc {
 	ASSERT_NONE,
@@ -29,19 +27,19 @@ enum assert_rc {
 	ASSERT_ERROR,
 };
 
-# ifndef MAX_HANDLE_SZ
+#ifndef MAX_HANDLE_SZ
 
-#  define MAX_HANDLE_SZ 128
+# define MAX_HANDLE_SZ 128
 
 struct file_handle {
 	unsigned int handle_bytes;
 	int handle_type;
 	unsigned char f_handle[0];
 };
-# endif /* !MAX_HANDLE_SZ */
+#endif /* !MAX_HANDLE_SZ */
 
 
-void
+static void
 print_handle_data(unsigned char *bytes, unsigned int size)
 {
 	unsigned int len = MIN(size, MAX_HANDLE_SZ);
@@ -50,8 +48,8 @@ print_handle_data(unsigned char *bytes, unsigned int size)
 		printf("...");
 }
 
-# ifndef TEST_SECONTEXT
-void
+#ifndef TEST_SECONTEXT
+static void
 do_name_to_handle_at(kernel_ulong_t dirfd, const char *dirfd_str,
 		     kernel_ulong_t pathname, const char *pathname_str,
 		     kernel_ulong_t handle, const char *handle_str,
@@ -95,7 +93,7 @@ do_name_to_handle_at(kernel_ulong_t dirfd, const char *dirfd_str,
 	printf(", %s) = %s\n", flags_str, errstr);
 }
 
-void
+static void
 do_open_by_handle_at(kernel_ulong_t mount_fd,
 		     kernel_ulong_t handle, bool valid_handle, bool valid_data,
 		     kernel_ulong_t flags, const char *flags_str)
@@ -132,15 +130,15 @@ do_open_by_handle_at(kernel_ulong_t mount_fd,
 
 	printf("%s\n", sprintrc(rc));
 }
-# endif /* !TEST_SECONTEXT */
+#endif /* !TEST_SECONTEXT */
 
 struct strval {
 	kernel_ulong_t val;
 	const char *str;
 };
 
-# define STR16 "0123456789abcdef"
-# define STR64 STR16 STR16 STR16 STR16
+#define STR16 "0123456789abcdef"
+#define STR64 STR16 STR16 STR16 STR16
 
 int
 main(void)
@@ -187,11 +185,11 @@ main(void)
 	char *path_secontext = SECONTEXT_FILE(path);
 
 	assert(syscall(__NR_name_to_handle_at, fdcwd, path, handle, &mount_id,
-		flags | 1) == -1);
+		flags | 0xfc) == -1);
 	if (EINVAL != errno)
 		perror_msg_and_skip("name_to_handle_at");
 	printf("%s%s(AT_FDCWD, \"%s\"%s, {handle_bytes=0}, %p"
-	       ", AT_SYMLINK_FOLLOW|0x1) = -1 EINVAL (%m)\n",
+	       ", AT_SYMLINK_FOLLOW|0xfc)" RVAL_EINVAL,
 	       my_secontext, "name_to_handle_at",
 	       path, path_secontext,
 	       &mount_id);
@@ -201,13 +199,18 @@ main(void)
 	if (EOVERFLOW != errno)
 		perror_msg_and_skip("name_to_handle_at");
 	printf("%s%s(AT_FDCWD, \"%s\"%s, {handle_bytes=0 => %u}"
-	       ", %p, AT_SYMLINK_FOLLOW) = -1 EOVERFLOW (%m)\n",
+	       ", %p, AT_SYMLINK_FOLLOW)" RVAL_EOVERFLOW,
 	       my_secontext, "name_to_handle_at",
 	       path, path_secontext,
 	       handle->handle_bytes, &mount_id);
 
-	assert(syscall(__NR_name_to_handle_at, fdcwd, path, handle, &mount_id,
-		flags) == 0);
+	if (syscall(__NR_name_to_handle_at, fdcwd, path, handle, &mount_id,
+		    flags)) {
+		if (EOVERFLOW == errno)
+			perror_msg_and_skip("name_to_handle_at");
+		else
+			perror_msg_and_fail("name_to_handle_at");
+	}
 	printf("%s%s(AT_FDCWD, \"%s\"%s, {handle_bytes=%u"
 	       ", handle_type=%d, f_handle=",
 	       my_secontext, "name_to_handle_at",
@@ -222,9 +225,9 @@ main(void)
 	print_handle_data(handle->f_handle, handle->handle_bytes);
 	int rc = syscall(__NR_open_by_handle_at, -1, handle,
 		O_RDONLY | O_DIRECTORY);
-	printf("}, O_RDONLY|O_DIRECTORY) = %d %s (%m)\n", rc, errno2name());
+	printf("}, O_RDONLY|O_DIRECTORY) = %s\n", sprintrc(rc));
 
-# ifndef TEST_SECONTEXT
+#ifndef TEST_SECONTEXT
 	static const struct strval dirfds[] = {
 		{ (kernel_ulong_t) 0xdeadca57badda7a1ULL, "-1159878751" },
 		{ (kernel_ulong_t) 0x12345678ffffff9cULL, "AT_FDCWD" },
@@ -233,10 +236,12 @@ main(void)
 		{ (kernel_ulong_t) 0xdeadf15700000000ULL, "0" },
 		{ (kernel_ulong_t) 0xbadc0ded00001000ULL,
 			"AT_EMPTY_PATH" },
-		{ (kernel_ulong_t) 0xdeadc0deda7a1457ULL,
-			"AT_SYMLINK_FOLLOW|AT_EMPTY_PATH|0xda7a0057" },
-		{ (kernel_ulong_t) 0xdefaced1ffffebffULL,
-			"0xffffebff /* AT_??? */" },
+		{ (kernel_ulong_t) 0xdeadc0deda7a1657ULL,
+			"AT_HANDLE_MNT_ID_UNIQUE|AT_HANDLE_CONNECTABLE|"
+			"AT_HANDLE_FID|AT_SYMLINK_FOLLOW|AT_EMPTY_PATH|"
+			"0xda7a0054" },
+		{ (kernel_ulong_t) 0xdefaced1ffffe9fcULL,
+			"0xffffe9fc /* AT_??? */" },
 	};
 	static const kernel_ulong_t mount_fds[] = {
 		(kernel_ulong_t) 0xdeadca5701234567ULL,
@@ -289,22 +294,20 @@ main(void)
 		(kernel_ulong_t) (uintptr_t) bogus_mount_id,
 	};
 
-	unsigned int i;
-	unsigned int j;
-	unsigned int k;
-	unsigned int l;
-	unsigned int m;
-
 	snprintf(bogus_path1_addr, sizeof(bogus_path1_addr), "%p", bogus_path1);
 	snprintf(bogus_path1_after_addr, sizeof(bogus_path1_after_addr), "%p",
 		bogus_path1 + PATH1_SIZE);
 
-	for (i = 0; i < ARRAY_SIZE(dirfds); i++) {
-		for (j = 0; j < ARRAY_SIZE(paths); j++) {
-			for (k = 0; k < ARRAY_SIZE(name_handles); k++) {
-				for (l = 0; l < ARRAY_SIZE(mount_ids); l++) {
-					for (m = 0; m < ARRAY_SIZE(name_flags);
-					    m++) {
+	for (unsigned int i = 0;
+	     i < ARRAY_SIZE(dirfds); ++i) {
+		for (unsigned int j = 0;
+		     j < ARRAY_SIZE(paths); ++j) {
+			for (unsigned int k = 0;
+			     k < ARRAY_SIZE(name_handles); ++k) {
+				for (unsigned int l = 0;
+				     l < ARRAY_SIZE(mount_ids); ++l) {
+					for (unsigned int m = 0;
+					     m < ARRAY_SIZE(name_flags); ++m) {
 						do_name_to_handle_at(
 							dirfds[i].val,
 							dirfds[i].str,
@@ -322,9 +325,12 @@ main(void)
 		}
 	}
 
-	for (i = 0; i < ARRAY_SIZE(mount_fds); i++) {
-		for (j = 0; j < ARRAY_SIZE(open_handles); j++) {
-			for (k = 0; k < ARRAY_SIZE(open_flags); k++) {
+	for (unsigned int i = 0;
+	     i < ARRAY_SIZE(mount_fds); ++i) {
+		for (unsigned int j = 0;
+		     j < ARRAY_SIZE(open_handles); ++j) {
+			for (unsigned int k = 0;
+			     k < ARRAY_SIZE(open_flags); ++k) {
 				do_open_by_handle_at(mount_fds[i],
 						     open_handles[j].addr,
 						     open_handles[j].valid,
@@ -334,7 +340,7 @@ main(void)
 			}
 		}
 	}
-# endif
+#endif
 
 	/*
 	 * Tests with dirfd.
@@ -400,9 +406,3 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("__NR_name_to_handle_at && __NR_open_by_handle_at")
-
-#endif
